@@ -1,4 +1,5 @@
 <?php
+
 /**
  * Passwd module.
  * Module that will be used to change passwords of the user.
@@ -7,18 +8,15 @@ class PasswdModule extends Module {
 	/**
 	 * Process the incoming events that were fire by the client.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $actionData) {
 			if (isset($actionType)) {
 				try {
-					switch ($actionType) {
-						case 'save':
-							$this->save($actionData);
-							break;
-
-						default:
-							$this->handleUnknownActionType($actionType);
-					}
+					match ($actionType) {
+						'save' => $this->save($actionData),
+						default => $this->handleUnknownActionType($actionType),
+					};
 				}
 				catch (MAPIException $e) {
 					$this->sendFeedback(false, $this->errorDetailsFromException($e));
@@ -112,7 +110,7 @@ class PasswdModule extends Module {
 					return;
 				}
 			}
-			catch (MAPIException $e) {
+			catch (MAPIException) {
 				if (mapi_last_hresult() == MAPI_E_NO_ACCESS) {
 					$errorMessage = _('Your password is wrong or you have insufficient permission to change password');
 				}
