@@ -1,4 +1,5 @@
 <?php
+
 /**
  * Conversion utility functions for converting various data types and structures.
  */
@@ -77,7 +78,7 @@ class Conversion {
 
 					case PT_MV_STRING8:
 					case PT_MV_STRING8 | MVI_FLAG:
-						$mv_values = explode(";", $value);
+						$mv_values = explode(";", (string) $value);
 						$values = [];
 
 						foreach ($mv_values as $mv_value) {
@@ -95,7 +96,7 @@ class Conversion {
 
 					case PT_BINARY:
 						if (!empty($value)) {
-							$properties[$mapi_property] = hex2bin($value);
+							$properties[$mapi_property] = hex2bin((string) $value);
 						}
 						break;
 
@@ -168,7 +169,7 @@ class Conversion {
 
 			switch (mapi_prop_type($property)) {
 				case PT_BINARY:
-					$value = bin2hex($value);
+					$value = bin2hex((string) $value);
 					break;
 
 				case PT_MV_BINARY:
@@ -233,9 +234,9 @@ class Conversion {
 	 * @example json2property('subject') => 0x0037001e
 	 * @example this also works json2property('PR_SUBJECT') => 0x0037001e
 	 *
-	 * @param array $mapping props A mapping of property names to their corresponding MAPI property tags
-	 * @param string $prop property name
-	 * @param bool  $convertToSingleValued whether to convert the multi valued property tag to single valued or not
+	 * @param array  $mapping               props A mapping of property names to their corresponding MAPI property tags
+	 * @param string $prop                  property name
+	 * @param bool   $convertToSingleValued whether to convert the multi valued property tag to single valued or not
 	 *
 	 * @return int The property tag
 	 */
@@ -286,7 +287,7 @@ class Conversion {
 		if (is_integer($property)) {
 			// Retrieve constants categories, zcore provides them in 'Core'
 			foreach (get_defined_constants(true)['Core'] as $key => $value) {
-				if ($property == $value && substr($key, 0, 3) == 'PR_') {
+				if ($property == $value && str_starts_with($key, 'PR_')) {
 					return $key;
 				}
 			}
@@ -301,7 +302,7 @@ class Conversion {
 	 * Convert an JSON restriction structure into a MAPI SRestriction array.
 	 *
 	 * @param array $mapping An associative array mapping property keys to MAPI proptags
-	 * @param array $json The parsed JSON array data
+	 * @param array $json    The parsed JSON array data
 	 *
 	 * @return array MAPI restriction array compatible with MAPI extension restriction format
 	 */
@@ -336,7 +337,7 @@ class Conversion {
 				foreach ($json[1][PROPS] as $propTag => $propValue) {
 					$propTag = Conversion::json2property($mapping, $propTag);
 					if (mapi_prop_type($propTag) === PT_BINARY) {
-						$propValue = hex2bin($propValue);
+						$propValue = hex2bin((string) $propValue);
 					}
 					$props[$propTag] = $propValue;
 				}
@@ -355,11 +356,11 @@ class Conversion {
 					$type = mapi_prop_type($propTag);
 
 					if ($type === PT_BINARY) {
-						$propValue = hex2bin($propValue);
+						$propValue = hex2bin((string) $propValue);
 					}
 					elseif ($type === PT_MV_STRING8) {
 						// Convert multivalued strings to arrays
-						$mv_values = explode(";", $propValue);
+						$mv_values = explode(";", (string) $propValue);
 						$values = [];
 
 						foreach ($mv_values as $mv_value) {
@@ -436,7 +437,7 @@ class Conversion {
 
 				foreach ($restriction[1][PROPS] as $propTag => $propValue) {
 					if (mapi_prop_type($propTag) === PT_BINARY) {
-						$propValue = bin2hex($propValue);
+						$propValue = bin2hex((string) $propValue);
 					}
 					$props[Conversion::property2json($propTag)] = is_array($propValue) ? $propValue[$propTag] : $propValue;
 				}
@@ -457,7 +458,7 @@ class Conversion {
 
 				foreach ($restriction[1][VALUE] as $propTag => $propValue) {
 					if (mapi_prop_type($propTag) === PT_BINARY) {
-						$propValue = bin2hex($propValue);
+						$propValue = bin2hex((string) $propValue);
 					}
 
 					$value[Conversion::property2json($propTag)] = $propValue;
@@ -498,10 +499,10 @@ class Conversion {
 			// if the string starts with '0x' then we have
 			// an acceptable propTag on which we can work
 			// to change the MV_flag value
-			if (substr($propTag, 0, 2) == '0x') {
+			if (str_starts_with($propTag, '0x')) {
 				$propTag = hexdec($propTag);
 				$propTag &= ~MV_FLAG;
-				$propTag = '0x' . strtoupper(str_pad(dechex_32($propTag), 8, '0', STR_PAD_LEFT));
+				$propTag = '0x' . strtoupper(str_pad((string) dechex_32($propTag), 8, '0', STR_PAD_LEFT));
 			}
 		}
 		else {
@@ -529,7 +530,7 @@ class Conversion {
 					case 'replyentryid':
 					case 'replyguid':
 					case 'dam':
-						$action[$key] = hex2bin($value);
+						$action[$key] = hex2bin((string) $value);
 						break;
 
 					case 'adrlist':
@@ -542,7 +543,7 @@ class Conversion {
 								$addrkey = Conversion::json2property($mapping, $addrkey);
 
 								if (mapi_prop_type($addrkey) === PT_BINARY) {
-									$addrval = hex2bin($addrval);
+									$addrval = hex2bin((string) $addrval);
 								}
 
 								$recipient[$addrkey] = $addrval;
@@ -578,7 +579,7 @@ class Conversion {
 					case 'replyentryid':
 					case 'replyguid':
 					case 'dam':
-						$action[$key] = bin2hex($value);
+						$action[$key] = bin2hex((string) $value);
 						break;
 
 					case 'adrlist':
@@ -589,7 +590,7 @@ class Conversion {
 
 							foreach ($addr as $addrkey => $addrval) {
 								if (mapi_prop_type($addrkey) === PT_BINARY) {
-									$addrval = bin2hex($addrval);
+									$addrval = bin2hex((string) $addrval);
 								}
 
 								$recipient[Conversion::property2json($addrkey)] = $addrval;
@@ -774,13 +775,10 @@ class Conversion {
 	 * @return string iconv-compatible charset name
 	 */
 	public static function getCodepageCharset($codepage) {
-		if (isset(Conversion::$_CODEPAGES[$codepage])) {
-			return Conversion::$_CODEPAGES[$codepage];
-		}
 		// Defaulting to iso-8859-15 since it is more likely for someone to make a mistake in the codepage
 		// when using west-european charsets then when using other charsets since utf-8 is binary compatible
 		// with the bottom 7 bits of west-european
-		return "iso-8859-15";
+		return Conversion::$_CODEPAGES[$codepage] ?? "iso-8859-15";
 	}
 
 	/**
@@ -797,6 +795,7 @@ class Conversion {
 		if ($charset !== false) {
 			return $charset;
 		}
+
 		// Trying every encoding from $_CODEPAGES is pointless. There
 		// is at least one encoding where all imaginable input byte
 		// sequences are valid, and a heuristic would pick that even if
