@@ -64,6 +64,7 @@ class AppointmentListModule extends ListModule {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			if (isset($actionType)) {
@@ -71,27 +72,14 @@ class AppointmentListModule extends ListModule {
 					$store = $this->getActionStore($action);
 					$entryid = $this->getActionEntryID($action);
 
-					switch ($actionType) {
-						case "list":
-							$this->messageList($store, $entryid, $action, $actionType);
-							break;
-
-						case "search":
-							// @FIXME add functionality to handle private items
-							$this->search($store, $entryid, $action, $actionType);
-							break;
-
-						case "updatesearch":
-							$this->updatesearch($store, $entryid, $action);
-							break;
-
-						case "stopsearch":
-							$this->stopSearch($store, $entryid, $action);
-							break;
-
-						default:
-							$this->handleUnknownActionType($actionType);
-					}
+					match ($actionType) {
+						"list" => $this->messageList($store, $entryid, $action, $actionType),
+						// @FIXME add functionality to handle private items
+						"search" => $this->search($store, $entryid, $action, $actionType),
+						"updatesearch" => $this->updatesearch($store, $entryid, $action),
+						"stopsearch" => $this->stopSearch($store, $entryid, $action),
+						default => $this->handleUnknownActionType($actionType),
+					};
 				}
 				catch (MAPIException $e) {
 					if (isset($action['suppress_exception']) && $action['suppress_exception'] === true) {
@@ -111,6 +99,7 @@ class AppointmentListModule extends ListModule {
 	 * @param array  $action     the action data, sent by the client
 	 * @param string $actionType the action type, sent by the client
 	 */
+	#[Override]
 	public function messageList($store, $entryid, $action, $actionType) {
 		if ($store && $entryid) {
 			// initialize start and due date with false value so it will not take values from previous request
@@ -129,10 +118,11 @@ class AppointmentListModule extends ListModule {
 
 			if (!empty($action["timezone_iana"])) {
 				$this->tziana = $action["timezone_iana"];
+
 				try {
 					$this->tzdef = mapi_ianatz_to_tzdef($action['timezone_iana']);
 				}
-				catch (Exception $e) {
+				catch (Exception) {
 				}
 			}
 
@@ -191,7 +181,7 @@ class AppointmentListModule extends ListModule {
 					}
 
 					$isSearchFolder = isset($action['search_folder_entryid']);
-					$entryid = $isSearchFolder ? hex2bin($action['search_folder_entryid']) : $entryid;
+					$entryid = $isSearchFolder ? hex2bin((string) $action['search_folder_entryid']) : $entryid;
 
 					if (!is_array($entryid) && !is_array($store)) {
 						$entryid = [$entryid];
@@ -421,7 +411,7 @@ class AppointmentListModule extends ListModule {
 						// We will create a new Recurrence object with the opened message,
 						// so we can open the attachments. The attachments for this exception
 						// contains the categories property (if changed)
-						$msgEntryid = bin2hex($calendaritem[$this->properties["entryid"]]);
+						$msgEntryid = bin2hex((string) $calendaritem[$this->properties["entryid"]]);
 						if (!isset($openedMessages[$msgEntryid])) {
 							// Open the message and add it to the openedMessages property
 							$message = mapi_msgstore_openentry($store, $calendaritem[$this->properties["entryid"]]);
@@ -469,6 +459,7 @@ class AppointmentListModule extends ListModule {
 	 *
 	 * @return object item properties after processing private items
 	 */
+	#[Override]
 	public function processPrivateItem($item) {
 		if ($this->startdate && $this->enddate) {
 			if ($this->checkPrivateItem($item)) {
@@ -501,11 +492,7 @@ class AppointmentListModule extends ListModule {
 		$start_a = $a["props"]["startdate"];
 		$start_b = $b["props"]["startdate"];
 
-		if ($start_a == $start_b) {
-			return 0;
-		}
-
-		return ($start_a < $start_b) ? -1 : 1;
+		return $start_a <=> $start_b;
 	}
 
 	/**
@@ -521,7 +508,7 @@ class AppointmentListModule extends ListModule {
 		// all-day events) or was imported from a system which doesn't set it.
 		$isTzdefstartSet = isset($calendaritem['props']['tzdefstart']);
 		$tzdefstart = $isTzdefstartSet ?
-			hex2bin($calendaritem['props']['tzdefstart']) :
+			hex2bin((string) $calendaritem['props']['tzdefstart']) :
 			mapi_ianatz_to_tzdef("Etc/UTC");
 
 		// queryrows only returns 510 chars max, so if tzdef is longer than that
@@ -530,7 +517,7 @@ class AppointmentListModule extends ListModule {
 		if (strlen($tzdefstart) > 500 && $isTzdefstartSet) {
 			if (!isset($openedMessages[$calendaritem['entryid']])) {
 				// Open the message and add it to the openedMessages property
-				$openedMessages[$calendaritem['entryid']] = mapi_msgstore_openentry($store, hex2bin($calendaritem['entryid']));
+				$openedMessages[$calendaritem['entryid']] = mapi_msgstore_openentry($store, hex2bin((string) $calendaritem['entryid']));
 			}
 			$tzdefstart = streamProperty($openedMessages[$calendaritem['entryid']], $this->properties['tzdefstart']);
 		}
@@ -547,16 +534,18 @@ class AppointmentListModule extends ListModule {
 			// if the appointment does not start at midnight
 			if ((int) $clientDate->format("His") != 0) {
 				$clientMidnight = DateTimeImmutable::createFromFormat(
-					"Y-m-d H:i:s", $clientDate->format("Y-m-d ") . "00:00:00",
-					$clientDate->getTimezone());
+					"Y-m-d H:i:s",
+					$clientDate->format("Y-m-d ") . "00:00:00",
+					$clientDate->getTimezone()
+				);
 				$interval = $clientDate->getTimestamp() - $clientMidnight->getTimestamp();
 				// The code here is based on assumption that if the interval
 				// is greater than 12 hours then the appointment takes place
 				// on the day before or after. This should be fine for all the
 				// timezones which do not exceed 12 hour difference to UTC.
 				$localStart = $interval > 0 ?
-					$calendaritem['props']['startdate'] - ($interval < 43200 ? $interval : $interval - 86400):
-					$calendaritem['props']['startdate'] + ($interval > -43200 ? $interval : $interval - 86400) ;
+					$calendaritem['props']['startdate'] - ($interval < 43200 ? $interval : $interval - 86400) :
+					$calendaritem['props']['startdate'] + ($interval > -43200 ? $interval : $interval - 86400);
 				$calendaritem['props']['startdate'] = $calendaritem['props']['commonstart'] = $localStart;
 				$calendaritem['props']['duedate'] = $calendaritem['props']['commonend'] = $localStart + $duration;
 			}
@@ -589,14 +578,14 @@ class AppointmentListModule extends ListModule {
 	}
 
 	/**
-	 * Adds items to return items list
+	 * Adds items to return items list.
 	 *
 	 * @param object $store
-	 * @param array  $calendaritem
 	 * @param array  $openedMessages
 	 * @param mixed  $start          startdate of the interval
 	 * @param mixed  $end            enddate of the interval
 	 * @param array  $items
+	 * @param mixed  $item
 	 */
 	private function addItems($store, &$item, &$openedMessages, $start, $end, &$items) {
 		$item = $this->processPrivateItem($item);
@@ -616,8 +605,8 @@ class AppointmentListModule extends ListModule {
 			// may have changed, so it's necessary to check again if they are
 			// still in the requested interval.
 			if (($start <= $item["props"]["startdate"] && $end > $item['props']['startdate']) ||
-			    ($start < $item["props"]["duedate"] && $end >= $item['props']['duedate']) ||
-			    ($start > $item["props"]["startdate"] && $end < $item['props']['duedate'])) {
+				($start < $item["props"]["duedate"] && $end >= $item['props']['duedate']) ||
+				($start > $item["props"]["startdate"] && $end < $item['props']['duedate'])) {
 				array_push($items, $item);
 			}
 		}
@@ -634,8 +623,8 @@ class AppointmentListModule extends ListModule {
 	public function getFreebusyItems($store, $folderEntryid, $start, $end) {
 		$items = [];
 		$storeProps = mapi_getprops($store, [PR_ENTRYID, PR_MAILBOX_OWNER_ENTRYID]);
-		$folderEntryid = bin2hex($folderEntryid);
-		$storeEntryid = bin2hex($storeProps[PR_ENTRYID]);
+		$folderEntryid = bin2hex((string) $folderEntryid);
+		$storeEntryid = bin2hex((string) $storeProps[PR_ENTRYID]);
 		// if start was not set, get items one month back
 		if ($start === false) {
 			$start = time() - 2592000;
