@@ -2,7 +2,7 @@
 
 /**
  * Create Mail ItemModule
- * Module which openes, creates, saves and deletes an item. It
+ * Module which opens, creates, saves and deletes an item. It
  * extends the Module class.
  */
 class CreateMailItemModule extends ItemModule {
@@ -26,6 +26,7 @@ class CreateMailItemModule extends ItemModule {
 	 * @param string $entryid       entryid of the message
 	 * @param array  $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function save($store, $parententryid, $entryid, $action) {
 		$result = false;
 		$send = false;
@@ -51,7 +52,7 @@ class CreateMailItemModule extends ItemModule {
 
 			// Set message flags first, because this has to be possible even if the user does not have write permissions
 			if (isset($action['props'], $action['props']['message_flags']) && $entryid) {
-				$msg_action = isset($action['message_action']) ? $action['message_action'] : false;
+				$msg_action = $action['message_action'] ?? false;
 				$result = $GLOBALS['operations']->setMessageFlag($store, $entryid, $action['props']['message_flags'], $msg_action, $messageProps);
 
 				unset($action['props']['message_flags']);
@@ -96,8 +97,8 @@ class CreateMailItemModule extends ItemModule {
 						 * OR
 						 * we need to copy ONLY original inline(HIDDEN) attachments when it is reply/replyall message.
 						 */
-						$copyFromMessage = hex2bin($action['message_action']['source_entryid']);
-						$copyFromStore = hex2bin($action['message_action']['source_store_entryid']);
+						$copyFromMessage = hex2bin((string) $action['message_action']['source_entryid']);
+						$copyFromStore = hex2bin((string) $action['message_action']['source_store_entryid']);
 						$copyFromAttachNum = !empty($action['message_action']['source_attach_num']) ? $action['message_action']['source_attach_num'] : false;
 						$copyAttachments = true;
 
@@ -126,19 +127,19 @@ class CreateMailItemModule extends ItemModule {
 
 				if ($send) {
 					// Allowing to hook in just before the data sent away to be sent to the client
-					$succes = true;
+					$success = true;
 					$GLOBALS['PluginManager']->triggerHook('server.module.createmailitemmodule.beforesend', [
 						'moduleObject' => $this,
 						'store' => $store,
 						'entryid' => $entryid,
 						'action' => $action,
-						'success' => &$succes,
+						'success' => &$success,
 						'properties' => $this->properties,
 						'messageProps' => $messageProps,
 						'parententryid' => $parententryid,
 					]);
 					// Break out, hook should use sendFeedback to return a response to the client.
-					if (!$succes) {
+					if (!$success) {
 						return;
 					}
 
@@ -186,7 +187,7 @@ class CreateMailItemModule extends ItemModule {
 						$action["recipients"]["remove"] = $members["remove"];
 					}
 
-					$error = $GLOBALS['operations']->submitMessage($store, $entryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, isset($action['recipients']) ? $action['recipients'] : [], isset($action['attachments']) ? $action['attachments'] : [], $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly, isset($action['props']['isHTML']) ? !$action['props']['isHTML'] : false);
+					$error = $GLOBALS['operations']->submitMessage($store, $entryid, Conversion::mapXML2MAPI($this->properties, $action['props']), $messageProps, $action['recipients'] ?? [], $action['attachments'] ?? [], $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly, isset($action['props']['isHTML']) ? !$action['props']['isHTML'] : false);
 
 					// If draft is sent from the drafts folder, delete notification
 					if (!$error) {
@@ -250,7 +251,7 @@ class CreateMailItemModule extends ItemModule {
 						array_push($propertiesToDelete, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_SEARCH_KEY);
 					}
 
-					$result = $GLOBALS['operations']->saveMessage($store, $entryid, $parententryid, $mapiProps, $messageProps, isset($action['recipients']) ? $action['recipients'] : [], isset($action['attachments']) ? $action['attachments'] : [], $propertiesToDelete, $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly);
+					$result = $GLOBALS['operations']->saveMessage($store, $entryid, $parententryid, $mapiProps, $messageProps, $action['recipients'] ?? [], $action['attachments'] ?? [], $propertiesToDelete, $copyFromMessage, $copyAttachments, false, $copyInlineAttachmentsOnly);
 
 					// Update the client with the (new) entryid and parententryid to allow the draft message to be removed when submitting.
 					// this will also update rowids of attachments which is required when deleting attachments
@@ -326,10 +327,10 @@ class CreateMailItemModule extends ItemModule {
 		$metaData = [];
 		if (isset($action["props"]["source_message_info"]) && !empty($action["props"]["source_message_info"])) {
 			if (isset($action["props"]['sent_representing_entryid']) && !empty($action["props"]['sent_representing_entryid'])) {
-				$storeEntryid = hex2bin($action['message_action']['source_store_entryid']);
+				$storeEntryid = hex2bin((string) $action['message_action']['source_store_entryid']);
 			}
 			else {
-				$storeEntryid = hex2bin($action['store_entryid']);
+				$storeEntryid = hex2bin((string) $action['store_entryid']);
 			}
 			$metaData['source_message_info'] = $action["props"]["source_message_info"];
 			$metaData['storeEntryid'] = $storeEntryid;
@@ -337,10 +338,10 @@ class CreateMailItemModule extends ItemModule {
 			return $metaData;
 		}
 		if (isset($action["entryid"]) && !empty($action["entryid"])) {
-			$storeEntryid = hex2bin($action['store_entryid']);
+			$storeEntryid = hex2bin((string) $action['store_entryid']);
 			$store = $GLOBALS['mapisession']->openMessageStore($storeEntryid);
 
-			$entryid = hex2bin($action['entryid']);
+			$entryid = hex2bin((string) $action['entryid']);
 			$message = $GLOBALS['operations']->openMessage($store, $entryid);
 			$messageProps = mapi_getprops($message);
 
@@ -372,10 +373,10 @@ class CreateMailItemModule extends ItemModule {
 	 */
 	public function getSourceStoreEntryId($props) {
 		$sentRepresentingEntryid = $props['props']['sent_representing_entryid'];
-		$user = mapi_ab_openentry($GLOBALS['mapisession']->getAddressbook(), hex2bin($sentRepresentingEntryid));
+		$user = mapi_ab_openentry($GLOBALS['mapisession']->getAddressbook(), hex2bin((string) $sentRepresentingEntryid));
 		$userProps = mapi_getprops($user, [PR_EMAIL_ADDRESS]);
 
-		return $GLOBALS['mapisession']->getStoreEntryIdOfUser(strtolower($userProps[PR_EMAIL_ADDRESS]));
+		return $GLOBALS['mapisession']->getStoreEntryIdOfUser(strtolower((string) $userProps[PR_EMAIL_ADDRESS]));
 	}
 
 	/**
@@ -396,9 +397,9 @@ class CreateMailItemModule extends ItemModule {
 			 * Here 66 represents the REPLY action type. same way 67 and 68 is represent
 			 * REPLY ALL and FORWARD respectively.
 			 */
-			$mailActionType = substr($sourceMsgInfo['source_message_info'], 24, 2);
+			$mailActionType = substr((string) $sourceMsgInfo['source_message_info'], 24, 2);
 			// get the entry id of origanal mail's.
-			$originalEntryid = substr($sourceMsgInfo['source_message_info'], 48);
+			$originalEntryid = substr((string) $sourceMsgInfo['source_message_info'], 48);
 			$entryid = hex2bin($originalEntryid);
 
 			$store = $GLOBALS['mapisession']->openMessageStore($sourceMsgInfo['storeEntryid']);
