@@ -38,6 +38,7 @@ class ItemModule extends Module {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			if (!isset($actionType)) {
@@ -82,7 +83,7 @@ class ItemModule extends Module {
 							case "declineMeetingRequest":
 							case "acceptMeetingRequest":
 								$message = $GLOBALS["operations"]->openMessage($store, $entryid);
-								$basedate = (isset($action['basedate']) ? $action['basedate'] : false);
+								$basedate = ($action['basedate'] ?? false);
 								$delete = false;
 
 								if ($basedate) {
@@ -118,16 +119,16 @@ class ItemModule extends Module {
 								// @FIXME: fix body
 								$body = false;
 								if (isset($action["props"]["isHTML"]) && $action["props"]["isHTML"] === true) {
-									$body = isset($action["props"]["html_body"]) ? $action["props"]["html_body"] : false;
+									$body = $action["props"]["html_body"] ?? false;
 								}
 								else {
-									$body = isset($action["props"]["body"]) ? $action["props"]["body"] : false;
+									$body = $action["props"]["body"] ?? false;
 								}
 
 								if ($action["message_action"]["action_type"] == "acceptMeetingRequest") {
 									$tentative = $action["message_action"]["responseType"] === olResponseTentative;
-									$newProposedStartTime = isset($action["message_action"]["proposed_starttime"]) ? $action["message_action"]["proposed_starttime"] : false;
-									$newProposedEndTime = isset($action["message_action"]["proposed_endtime"]) ? $action["message_action"]["proposed_endtime"] : false;
+									$newProposedStartTime = $action["message_action"]["proposed_starttime"] ?? false;
+									$newProposedEndTime = $action["message_action"]["proposed_endtime"] ?? false;
 
 									// We are accepting MR from preview-read-mail so set delete the actual mail flag.
 									$delete = $req->isMeetingRequest($originalMessageProps[PR_MESSAGE_CLASS]);
@@ -157,14 +158,14 @@ class ItemModule extends Module {
 								if ($delete) {
 									// send TABLE_DELETE event because the message has moved
 									$this->sendFeedback(true);
-									$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_DELETE, $messageProps);
+									$GLOBALS["bus"]->notify(bin2hex((string) $messageProps[PR_PARENT_ENTRYID]), TABLE_DELETE, $messageProps);
 								}
 								else {
 									$this->addActionData("update", ["item" => Conversion::mapMAPI2XML($this->properties, $messageProps)]);
 									$GLOBALS["bus"]->addData($this->getResponseData());
 
 									// send TABLE_SAVE event because an occurrence is deleted
-									$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
+									$GLOBALS["bus"]->notify(bin2hex((string) $messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
 								}
 
 								break;
@@ -193,13 +194,13 @@ class ItemModule extends Module {
 
 								$this->sendFeedback(true);
 								if ($result !== false) {
-									$GLOBALS["bus"]->notify(bin2hex($result[PR_PARENT_ENTRYID]), TABLE_DELETE, $result);
+									$GLOBALS["bus"]->notify(bin2hex((string) $result[PR_PARENT_ENTRYID]), TABLE_DELETE, $result);
 								}
 
 								$props = mapi_getprops($message, [PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID]);
 								if (!$tr->isTaskRequest()) {
 									unset($props[PR_MESSAGE_CLASS]);
-									$GLOBALS["bus"]->notify(bin2hex($props[PR_PARENT_ENTRYID]), $isAccept ? TABLE_SAVE : TABLE_DELETE, $props);
+									$GLOBALS["bus"]->notify(bin2hex((string) $props[PR_PARENT_ENTRYID]), $isAccept ? TABLE_SAVE : TABLE_DELETE, $props);
 								}
 								break;
 
@@ -252,15 +253,15 @@ class ItemModule extends Module {
 								// @FIXME: may be we can remove this body check any get it while declining meeting 'body'
 								$body = false;
 								if (isset($action["props"]["isHTML"]) && $action["props"]["isHTML"] === true) {
-									$body = isset($action["props"]["html_body"]) ? $action["props"]["html_body"] : false;
+									$body = $action["props"]["html_body"] ?? false;
 								}
 								else {
-									$body = isset($action["props"]["body"]) ? $action["props"]["body"] : false;
+									$body = $action["props"]["body"] ?? false;
 								}
 								$req->doDecline(true, $basedate, $body);
 
 								$messageProps = mapi_getprops($message, [PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID]);
-								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), $basedate ? TABLE_SAVE : TABLE_DELETE, $messageProps);
+								$GLOBALS["bus"]->notify(bin2hex((string) $messageProps[PR_PARENT_ENTRYID]), $basedate ? TABLE_SAVE : TABLE_DELETE, $messageProps);
 
 								break;
 
@@ -274,7 +275,7 @@ class ItemModule extends Module {
 								// generate an exception. So when the basedate is provided, we actually
 								// perform a save rather then delete.
 								if (isset($action['basedate']) && !empty($action['basedate'])) {
-									$this->save($store, $parententryid, $entryid, $action, "delete");
+									$this->save($store, $parententryid, $entryid, $action);
 								}
 								else {
 									$this->delete($store, $parententryid, $entryid, $action);
@@ -305,6 +306,7 @@ class ItemModule extends Module {
 	 * @param string     $entryid       entryid of the message
 	 * @param array      $action        the action data, sent by the client
 	 */
+	#[Override]
 	public function handleException(&$e, $actionType = null, $store = null, $parententryid = null, $entryid = null, $action = null) {
 		if (is_null($e->displayMessage)) {
 			switch ($actionType) {
@@ -423,9 +425,7 @@ class ItemModule extends Module {
 			}
 			Log::Write(
 				LOGLEVEL_ERROR,
-				"itemmodule::handleException():" . $actionType . ": " . $e->displayMessage,
-				$e,
-				$action
+				"itemmodule::handleException():" . $actionType . ": " . $e->displayMessage
 			);
 		}
 
@@ -500,7 +500,7 @@ class ItemModule extends Module {
 
 								// send update to maillistmodule that meeting request is updated with out of date flag
 								$messageProps = mapi_getprops($message, [PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID]);
-								$GLOBALS['bus']->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
+								$GLOBALS['bus']->notify(bin2hex((string) $messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
 							}
 							else {
 								/*
@@ -844,11 +844,11 @@ class ItemModule extends Module {
 			$calendarItemProps = mapi_getprops($calendarItem, [PR_STORE_ENTRYID, PR_PARENT_ENTRYID, PR_ENTRYID, $meetingRequestObject->proptags['updatecounter'], $meetingRequestObject->proptags['goid']]);
 
 			// Store calendar item's necessary properties in props array.
-			$props['appointment_store_entryid'] = bin2hex($calendarItemProps[PR_STORE_ENTRYID]);
-			$props['appointment_parent_entryid'] = bin2hex($calendarItemProps[PR_PARENT_ENTRYID]);
-			$props['appointment_entryid'] = bin2hex($calendarItemProps[PR_ENTRYID]);
+			$props['appointment_store_entryid'] = bin2hex((string) $calendarItemProps[PR_STORE_ENTRYID]);
+			$props['appointment_parent_entryid'] = bin2hex((string) $calendarItemProps[PR_PARENT_ENTRYID]);
+			$props['appointment_entryid'] = bin2hex((string) $calendarItemProps[PR_ENTRYID]);
 
-			$props['appointment_updatecounter'] = isset($calendarItemProps[$meetingRequestObject->proptags['updatecounter']]) ? $calendarItemProps[$meetingRequestObject->proptags['updatecounter']] : 0;
+			$props['appointment_updatecounter'] = $calendarItemProps[$meetingRequestObject->proptags['updatecounter']] ?? 0;
 
 			$messageProps = mapi_getprops($meetingRequestObject->message, [$meetingRequestObject->proptags['goid']]);
 
@@ -863,7 +863,7 @@ class ItemModule extends Module {
 				if ($exception !== false) {
 					// we are able to find the exception then get updatecounter
 					$exceptionProps = mapi_getprops($exception, [$meetingRequestObject->proptags['updatecounter']]);
-					$props['appointment_updatecounter'] = isset($exceptionProps[$meetingRequestObject->proptags['updatecounter']]) ? $exceptionProps[$meetingRequestObject->proptags['updatecounter']] : 0;
+					$props['appointment_updatecounter'] = $exceptionProps[$meetingRequestObject->proptags['updatecounter']] ?? 0;
 				}
 			}
 
@@ -945,12 +945,12 @@ class ItemModule extends Module {
 			// if basedate is specified then we have created exception in recurring meeting request
 			// so send notification of creation of exception
 			$messageProps = mapi_getprops($message, [PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID]);
-			$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
+			$GLOBALS["bus"]->notify(bin2hex((string) $messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
 		}
 		else {
 			// for normal/recurring meetings send delete notification
 			$messageProps = mapi_getprops($message, [PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID]);
-			$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_DELETE, $messageProps);
+			$GLOBALS["bus"]->notify(bin2hex((string) $messageProps[PR_PARENT_ENTRYID]), TABLE_DELETE, $messageProps);
 		}
 	}
 
@@ -974,6 +974,6 @@ class ItemModule extends Module {
 
 		// Notify the bus that the message has been deleted
 		$messageProps = mapi_getprops($message, [PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID]);
-		$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), $basedate ? TABLE_SAVE : TABLE_DELETE, $messageProps);
+		$GLOBALS["bus"]->notify(bin2hex((string) $messageProps[PR_PARENT_ENTRYID]), $basedate ? TABLE_SAVE : TABLE_DELETE, $messageProps);
 	}
 }
